foojank

package module
v0.0.0-...-f707dbd Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 25, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

README

Vessel

Foojank is a prototype of an agent for foojank command-and-control framework.

Foojank uses NATS as a command-and-control server. NATS, a widely used message broker, is commonly used in IoT and cloud systems to facilitate communication between distributed services. NATS offers a persistence layer known as JetStream, enabling it to store messages on the server even when the receiver is offline. Additionally, NATS provides an object store that can be utilized for storing files.

Foojank leverages the NATS features to offer:

  • Asynchronous or real-time communication with Agents over TCP or WebSockets.
  • Server-based storage for file sharing and data exfiltration.
  • JWT-based authentication and authorization.
  • Full observability.
  • Extensibility.

Foojank is currently compatible only with our prototype agent, Vessel. However, we plan to implement support for integrating custom agents into the framework in the future.

Installation

TODO

Usage

TODO

License

This software is distributed under the Apache License Version 2.0 found in the LICENSE file.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Version

func Version() string

Types

This section is empty.

Directories

Path Synopsis
cmd
vessel command
internal
log

Jump to